@@ -99,7 +99,7 @@ class Perceiver(nn.Module):
         # calculate fourier encoded positions in the range of [-1, 1], for all axis
 
         axis_pos = list(map(lambda size: torch.linspace(-1., 1., steps = size, device = device), axis))
-        pos = torch.stack(torch.meshgrid(*axis_pos), dim = -1)
+        pos = torch.stack(torch.meshgrid(*axis_pos, indexing = 'ij'), dim = -1)
         enc_pos = fourier_encode(pos, self.max_freq, self.num_freq_bands, base = self.freq_base)
         enc_pos = rearrange(enc_pos, '... n d -> ... (n d)')
         enc_pos = repeat(enc_pos, '... -> b ...', b = b)
